<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'					=> 'Installation',
'L_WRONG_PHP_VERSION'				=> 'PluXml requires PHP 5 or higher',
'L_SELECT_LANG'						=> 'Choose your language',
'L_INPUT_CHANGE'					=> 'Change',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Category 1',
'L_DEFAULT_CATEGORY_URL'			=> 'caregory-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Static 1',
'L_DEFAULT_STATIC_URL'				=> 'static-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'First article',
'L_DEFAULT_ARTICLE_URL'				=> 'first-article',
'L_DEFAULT_COMMENT_CONTENT'			=> 'This is a first comment !',
'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml is already set up !',
'L_ERR_MISSING_USER'				=> 'Please fill in the contributor\'s field !',
'L_ERR_MISSING_LOGIN'				=> 'Please fill the login field !',
'L_ERR_MISSING_PASSWORD'			=> 'Please fill the password field !',
'L_ERR_PASSWORD_CONFIRMATION'		=> 'Invalid password confirmation !',
'L_PLUXML_INSTALLATION'				=> 'PluXml installation',
'L_SITE_DESCRIPTION'				=> 'Blog or CMS, XML powered !',
'L_VERSION'							=> 'version',
'L_USERNAME'						=> 'Admin username',
'L_LOGIN'							=> 'Admin login',
'L_PASSWORD'						=> 'Password',
'L_PASSWORD_CONFIRMATION'			=> 'Confirm password',
'L_INPUT_INSTALL'					=> 'Install',
'L_TIMEZONE'						=> 'Time Zone',
'L_PWD_VERY_WEAK'					=> 'Very weak password',
'L_PWD_WEAK'						=> 'Weak password',
'L_PWD_GOOD'						=> 'Good password',
'L_PWD_STRONG'						=> 'Strong password',
);
?>